@@ -19,7 +19,7 @@ paths = [os.path.join(dirname, 'bokeh', name)
          for name in ['status', 'tasks', 'workers']]
 
 binname = 'bokeh.exe' if sys.platform.startswith('win') else 'bokeh'
-binname = os.path.join(os.path.dirname(sys.argv[0]), binname)
+binname = os.path.join(os.path.dirname(sys.executable), binname)
 
 logger = logging.getLogger(__file__)
 
@@ -85,8 +85,7 @@ class BokehWebInterface(object):
             self.process.start()
         else:
             import subprocess
-            self.process = subprocess.Popen(args, stdout=subprocess.PIPE,
-                    stderr=subprocess.PIPE)
+            self.process = subprocess.Popen(args)
 
         if not quiet:
             logger.info(" Bokeh UI at:  http://%s:%d/status/"
