@@ -3,8 +3,10 @@
 from __future__ import print_function, division, absolute_import
 
 from collections import deque
+import sys
 import json
 import os
+import logging
 from time import time
 
 from tornado import gen
@@ -16,7 +18,9 @@ from distributed.core import read
 from distributed.diagnostics.eventstream import eventstream
 from distributed.bokeh.status_monitor import task_stream_append
 import distributed.bokeh
-from distributed.utils import log_errors
+
+
+logger = logging.getLogger(__name__)
 
 client = AsyncHTTPClient()
 
@@ -32,30 +36,36 @@ else:
                'http-port': 9786}
 
 
-
 @gen.coroutine
 def task_events(interval, deque, times, index, rectangles, workers, last_seen):
     i = 0
-    with log_errors():
+    try:
         stream = yield eventstream('%(host)s:%(tcp-port)d' % options, 0.100)
         while True:
-            try:
-                msgs = yield read(stream)
-            except StreamClosedError:
-                break
-            else:
-                if not msgs:
-                    continue
+            msgs = yield read(stream)
+            if not msgs:
+                continue
 
-                last_seen[0] = time()
-                for msg in msgs:
-                    if 'compute_start' in msg:
-                        deque.append(msg)
-                        times.append(msg['compute_start'])
-                        index.append(i); i += 1
-                        if msg.get('transfer_start') is not None:
-                            index.append(i); i += 1
-                        task_stream_append(rectangles, msg, workers)
+            last_seen[0] = time()
+            for msg in msgs:
+                if 'compute_start' in msg:
+                    deque.append(msg)
+                    times.append(msg['compute_start'])
+                    index.append(i)
+                    i += 1
+                    if msg.get('transfer_start') is not None:
+                        index.append(i)
+                        i += 1
+                    if msg.get('disk_load_start') is not None:
+                        index.append(i)
+                        i += 1
+                    task_stream_append(rectangles, msg, workers)
+    except StreamClosedError:
+        pass  # don't log StreamClosedErrors
+    except Exception as e:
+        logger.exception(e)
+    finally:
+        sys.exit(0)
 
 
 n = 100000
