@@ -4,7 +4,7 @@ from distutils.version import LooseVersion
 
 from tornado import gen
 
-from .executor import Executor, _wait
+from .client import Client, _wait
 from .utils import ignoring
 
 
@@ -15,21 +15,21 @@ from .utils import ignoring
 joblib = sk_joblib = None
 with ignoring(ImportError):
     import joblib
-    if LooseVersion(joblib.__version__) < '0.10.0':
+    if LooseVersion(joblib.__version__) < '0.10.2':
         joblib = None
 with ignoring(ImportError):
     import sklearn.externals.joblib as sk_joblib
-    if LooseVersion(sk_joblib.__version__) < '0.10.0':
+    if LooseVersion(sk_joblib.__version__) < '0.10.2':
         sk_joblib = None
 
 if joblib:
-    from joblib._parallel_backends import (ParallelBackendBase,
+    from joblib.parallel import (ParallelBackendBase,
         AutoBatchingMixin)
 elif sk_joblib:
-    from sklearn.externals.joblib._parallel_backends import (
+    from sklearn.externals.joblib.parallel import (
         ParallelBackendBase, AutoBatchingMixin)
 else:
-    raise RuntimeError("Joblib backend requires either `joblib` >= '0.10.0' "
+    raise RuntimeError("Joblib backend requires either `joblib` >= '0.10.2' "
                        " or `sklearn` > '0.17.1'. Please install or upgrade")
 
 
@@ -38,19 +38,19 @@ class DistributedBackend(ParallelBackendBase, AutoBatchingMixin):
     MAX_IDEAL_BATCH_DURATION = 1.0
 
     def __init__(self, scheduler_host='127.0.0.1:8786', loop=None):
-        self.executor = Executor(scheduler_host, loop=loop)
+        self.client = Client(scheduler_host, loop=loop)
         self.futures = set()
 
     def configure(self, n_jobs=1, parallel=None, **backend_args):
         return self.effective_n_jobs(n_jobs)
 
     def effective_n_jobs(self, n_jobs=1):
-        return sum(self.executor.ncores().values())
+        return sum(self.client.ncores().values())
 
     def apply_async(self, func, *args, **kwargs):
         callback = kwargs.pop('callback', None)
         kwargs['pure'] = False
-        future = self.executor.submit(func, *args, **kwargs)
+        future = self.client.submit(func, *args, **kwargs)
         self.futures.add(future)
 
         @gen.coroutine
@@ -59,15 +59,15 @@ class DistributedBackend(ParallelBackendBase, AutoBatchingMixin):
             self.futures.remove(future)
             callback(result)  # gets called in separate thread
 
-        self.executor.loop.add_callback(callback_wrapper)
+        self.client.loop.add_callback(callback_wrapper)
 
         future.get = future.result  # monkey patch to achieve AsyncResult API
         return future
 
     def abort_everything(self, ensure_ready=True):
-        # Tell the executor to cancel any task submitted via this instance
+        # Tell the client to cancel any task submitted via this instance
         # as joblib.Parallel will never access those results.
-        self.executor.cancel(self.futures)
+        self.client.cancel(self.futures)
         self.futures.clear()
 
 
