@@ -1,18 +1,25 @@
 from __future__ import print_function, division, absolute_import
 
 from datetime import datetime, timedelta
+import json
 import logging
 from multiprocessing import Process, Queue, queues
 import os
 import shutil
+import subprocess
+import sys
+import tempfile
+from time import time, sleep
 
 from tornado.ioloop import IOLoop
 from tornado import gen
 
+from .compatibility import JSONDecodeError
 from .core import Server, rpc, write
-from .utils import get_ip, ignoring, log_errors
-from .worker import _ncores
+from .utils import get_ip, ignoring, log_errors, tmpfile
+from .worker import _ncores, Worker, run
 
+environment = os.path.dirname(sys.executable)
 
 logger = logging.getLogger(__name__)
 
@@ -24,11 +31,21 @@ class Nanny(Server):
     """
     def __init__(self, scheduler_ip, scheduler_port, ip=None, worker_port=0,
                  ncores=None, loop=None, local_dir=None, services=None,
-                 name=None, **kwargs):
+                 name=None, memory_limit=None, environment=environment,
+                 quiet=False, **kwargs):
         self.ip = ip or get_ip()
         self.worker_port = None
         self._given_worker_port = worker_port
         self.ncores = ncores or _ncores
+        if not local_dir:
+            local_dir = tempfile.mkdtemp(prefix='nanny-')
+            self._should_cleanup_local_dir = True
+            def _cleanup_local_dir():
+                if os.path.exists(local_dir):
+                    shutil.rmtree(local_dir)
+            atexit.register(_cleanup_local_dir)
+        else:
+            self._should_cleanup_local_dir = False
         self.local_dir = local_dir
         self.worker_dir = ''
         self.status = None
@@ -37,11 +54,15 @@ class Nanny(Server):
         self.scheduler = rpc(ip=scheduler_ip, port=scheduler_port)
         self.services = services
         self.name = name
+        self.memory_limit = memory_limit
+        self.environment = environment
+        self.quiet = quiet
 
         handlers = {'instantiate': self.instantiate,
                     'kill': self._kill,
                     'terminate': self._close,
-                    'monitor_resources': self.monitor_resources}
+                    'monitor_resources': self.monitor_resources,
+                    'run': self.run}
 
         super(Nanny, self).__init__(handlers, io_loop=self.loop, **kwargs)
 
@@ -49,7 +70,7 @@ class Nanny(Server):
     def _start(self, port=0):
         """ Start nanny, start local process, start watching """
         self.listen(port)
-        # logger.info('        Start Nanny at: %20s:%d', self.ip, self.port)
+        logger.info('        Start Nanny at: %20s:%d', self.ip, self.port)
         yield self.instantiate()
         self.loop.add_callback(self._watch)
         assert self.worker_port
@@ -101,8 +122,14 @@ class Nanny(Server):
                 logger.exception(e)
 
             if self.process:
-                self.process.terminate()
-                self.process.join(timeout=timeout)
+                with ignoring(OSError):
+                    self.process.terminate()
+                processes_to_close.remove(self.process)
+
+                start = time()
+                while self.process.poll() is None and time() < start + timeout:
+                    sleep(0.01)
+
                 self.process = None
                 self.cleanup()
                 logger.info("Nanny %s:%d kills worker process %s:%d",
@@ -110,41 +137,57 @@ class Nanny(Server):
         raise gen.Return('OK')
 
     @gen.coroutine
-    def instantiate(self, stream=None):
+    def instantiate(self, stream=None, environment=None):
         """ Start a local worker process
 
         Blocks until the process is up and the scheduler is properly informed
         """
-        if self.process and self.process.is_alive():
-            raise ValueError("Existing process still alive. Please kill first")
-        q = Queue()
-        self.process = Process(target=run_worker,
-                               args=(q, self.ip, self.scheduler.ip,
-                                     self.scheduler.port, self.ncores,
-                                     self.port, self._given_worker_port,
-                                     self.local_dir, self.services, self.name))
-        self.process.daemon = True
-        self.process.start()
-        while True:
-            try:
-                msg = q.get_nowait()
-                if isinstance(msg, Exception):
-                    raise msg
-                self.worker_port = msg['port']
-                assert self.worker_port
-                self.worker_dir = msg['dir']
-                break
-            except queues.Empty:
-                yield gen.sleep(0.1)
-        logger.info("Nanny %s:%d starts worker process %s:%d",
-                    self.ip, self.port, self.ip, self.worker_port)
-        q.close()
-        raise gen.Return('OK')
+        if environment:
+            if not os.path.isabs(environment):
+                environment = os.path.join(self.local_dir, environment)
+            self.environment = environment
+
+        with log_errors():
+            if self.process and self.process.poll() is None:
+                raise ValueError("Existing process still alive. Please kill first")
+            with tmpfile() as fn:
+                self.process = run_worker(self.environment, self.ip,
+                        self.scheduler.ip, self.scheduler.port, self.ncores,
+                        self.port, self._given_worker_port, self.name,
+                        self.memory_limit, self.loop, fn, self.quiet)
+
+                while not os.path.exists(fn):
+                    yield gen.sleep(0.01)
+
+                while True:
+                    try:
+                        with open(fn) as f:
+                            msg = json.load(f)
+                        self.worker_port = msg['port']
+                        self.worker_dir = msg['local_directory']
+                        break
+                    except JSONDecodeError:
+                        yield gen.sleep(0.01)
+
+            logger.info("Nanny %s:%d starts worker process %s:%d",
+                        self.ip, self.port, self.ip, self.worker_port)
+            raise gen.Return('OK')
+
+    def run(self, *args, **kwargs):
+        return run(self, *args, **kwargs)
 
     def cleanup(self):
         if self.worker_dir and os.path.exists(self.worker_dir):
             shutil.rmtree(self.worker_dir)
         self.worker_dir = None
+        if self.process:
+            with ignoring(OSError):
+                self.process.terminate()
+
+    def __del__(self):
+        if self._should_cleanup_local_dir and os.path.exists(self.local_dir):
+            shutil.rmtree(self.local_dir)
+        self.cleanup()
 
     @gen.coroutine
     def _watch(self, wait_seconds=0.10):
@@ -153,8 +196,9 @@ class Nanny(Server):
             if closing[0] or self.status == 'closed':
                 yield self._close()
                 break
-            elif self.process and not self.process.is_alive():
-                logger.warn("Discovered failed worker.  Restarting.  Status: %s", self.status)
+            elif self.process and self.process.poll() is not None:
+                logger.warn("Discovered failed worker.  Restarting. Status: %s",
+                            self.status)
                 self.cleanup()
                 yield self.scheduler.unregister(address=self.worker_address)
                 yield self.instantiate()
@@ -209,42 +253,56 @@ class Nanny(Server):
             yield gen.sleep(interval)
 
 
-def run_worker(q, ip, scheduler_ip, scheduler_port, ncores, nanny_port,
-        worker_port, local_dir, services, name):
-    """ Function run by the Nanny when creating the worker """
-    from distributed import Worker  # pragma: no cover
-    from tornado.ioloop import IOLoop  # pragma: no cover
-    IOLoop.clear_instance()  # pragma: no cover
-    loop = IOLoop()  # pragma: no cover
-    loop.make_current()  # pragma: no cover
-    worker = Worker(scheduler_ip, scheduler_port, ncores=ncores, ip=ip,
-                    service_ports={'nanny': nanny_port}, local_dir=local_dir,
-                    services=services, name=name, loop=loop)  # pragma: no cover
+def run_worker(environment, ip, scheduler_ip, scheduler_port, ncores,
+        nanny_port, worker_port, name, memory_limit, io_loop, fn, quiet):
 
-    @gen.coroutine  # pragma: no cover
-    def start():
-        try:  # pragma: no cover
-            yield worker._start(worker_port)  # pragma: no cover
-        except Exception as e:  # pragma: no cover
-            logger.exception(e)  # pragma: no cover
-            q.put(e)  # pragma: no cover
-        else:
-            assert worker.port  # pragma: no cover
-            q.put({'port': worker.port, 'dir': worker.local_dir})  # pragma: no cover
+    if environment.endswith('python'):
+        environment = os.path.dirname(environment)
+    if os.path.exists(os.path.join(environment, 'bin')):
+        environment = os.path.join(environment, 'bin')
+    executable = os.path.join(environment, 'python')
 
-    loop.add_callback(start)  # pragma: no cover
-    try:
-        loop.start()  # pragma: no cover
-    finally:
-        loop.stop()
-        loop.close(all_fds=True)
+    args = ['-m' 'distributed.cli.dask_worker']
+    if sys.platform.startswith('win'):
+        args.append('--scheduler')
+
+    args.extend(['%s:%d' %(scheduler_ip, scheduler_port),
+                 '--no-nanny',
+                 '--host', ip,
+                 '--worker-port', worker_port,
+                 '--nanny-port', nanny_port,
+                 '--nthreads', ncores,
+                 '--nprocs', 1,
+                 '--temp-filename', fn])
+
+    if name:
+        args.extend(['--name', name])
+
+    if memory_limit:
+        args.extend(['--memory-limit', memory_limit])
+
+    proc = subprocess.Popen([executable] + list(map(str, args)),
+            stderr=subprocess.PIPE if quiet else None)
+
+    processes_to_close.append(proc)
+
+    return proc
 
 
 import atexit
 
 closing = [False]
 
+processes_to_close = []
+
 def _closing():
+    for proc in processes_to_close:
+        if proc.poll() is not None:
+            try:
+                proc.terminate()
+            except OSError:
+                pass
+
     closing[0] = True
 
 atexit.register(_closing)
